about summary refs log tree commit diff
path: root/editor/pamthreshold.c
diff options
context:
space:
mode:
Diffstat (limited to 'editor/pamthreshold.c')
-rw-r--r--editor/pamthreshold.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/editor/pamthreshold.c b/editor/pamthreshold.c
index c5f48147..ceddff15 100644
--- a/editor/pamthreshold.c
+++ b/editor/pamthreshold.c
@@ -161,13 +161,13 @@ parseCommandLine(int                 argc,
     /* set the defaults */
     cmdlineP->width = cmdlineP->height = 0U;
 
     /* set the option description for optParseOptions3 */
     opt.opt_table     = option_def;
     opt.short_allowed = FALSE;           /* long options only */
     opt.allowNegNum   = FALSE;           /* we have no numbers at all */
 
     /* parse commandline, change argc, argv, and *cmdlineP */
-    optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
+    pm_optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
 
     if (cmdlineP->simple + localSpec + dualSpec > 1)
         pm_error("You may specify only one of -simple, -local, and -dual");
@@ -161,13 +161,13 @@ parseCommandLine(int                 argc,
     cmdlineP->width = cmdlineP->height = 0U;
 
-    /* set the option description for optParseOptions3 */
+    /* set the option description for pm_optParseOptions3 */
     opt.opt_table     = option_def;
     opt.short_allowed = FALSE;           /* long options only */